globals [
  clock            ;; increments each time tick
  spout-patches    ;; set in setup so we don't have to keep recomputing it
  spout-ycor       ;; location of the spouts
  surface-ycor     ;; initial location of the surface of the sand at the bottom
]

patches-own [
  next-color       ;; patches first all decide what color to change to, then all change
]

to setup
  locals [spout-space]
  ca
  set clock 0
  set surface-ycor -0.8 * screen-edge-y
  ask patches with [pycor < surface-ycor]
    [ set pcolor gray ]
  set spout-ycor round (screen-edge-y * 0.9)
  set spout-space round (screen-edge-x * 0.6)
  ;; now set up the blue spouts at spout-space intervals        
  set spout-patches patches with [(pxcor mod spout-space = 0) and
                                  (pycor = spout-ycor)]
  ask spout-patches
    [ set pcolor blue ]
end

to dump-sand
  ask patches with [(pycor < spout-ycor) and
                    (pycor > surface-ycor)]
    [ if random-float 100 < density
        [ set pcolor yellow ] ]
end

to go
  spout       
  move-all-sand
end

;; spouts sand particles depending on spacing (how often sand is released)
;; and the release-chance percent when the spacing interval is reached
to spout
  set clock (clock + 1)
  if clock >= spacing
    [ ask spout-patches with [random-float 100 <= release-chance]
        [ set pcolor-of patch-at 0 -1 yellow ]
      set clock 0 ]
end

;; implements the four rules given in the info tab
;; to all the yellow sand particles
to move-all-sand
  ask patches
    [ set next-color pcolor ]
  ask patches with [pcolor = yellow]
    [ ifelse (pcolor-of patch-at 0 -1 = black)
        [ move 0 ]
        [ ifelse (pcolor-of patch-at -1 -1 = yellow) and
                 (pcolor-of patch-at  1 -1 = black)
           [ move 1 ]
           [ ifelse (pcolor-of patch-at -1 -1 = black) and
                    (pcolor-of patch-at  1 -1 = yellow)
              [ move -1 ]
              [ if (pcolor-of patch-at 1 -1 = black) and
                   (pcolor-of patch-at -1 -1 = black)
                  [ move random-one-of [1 -1] ] ] ] ] ]
  ;; we do this in a separate "ask" so that all the patches decide
  ;; on their new colors before any of them actually change color
  ask patches
    [ set pcolor next-color ]
end

to move [x-offset];; patch procedure
  set next-color black
  set next-color-of (patch-at x-offset -1) yellow
end


; *** NetLogo Model Copyright Notice ***
;
; This model was created as part of the project: CONNECTED MATHEMATICS:
; MAKING SENSE OF COMPLEX PHENOMENA THROUGH BUILDING OBJECT-BASED PARALLEL
; MODELS (OBPML).  The project gratefully acknowledges the support of the
; National Science Foundation (Applications of Advanced Technologies
; Program) -- grant numbers RED #9552950 and REC #9632612.
;
; Copyright 1996 by Uri Wilensky. All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; This model was converted to NetLogo as part of the project:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN
; CLASSROOMS.  The project gratefully acknowledges the support of the
; National Science Foundation (REPP program) -- grant number REC #9814682.
; Converted from StarLogoT to NetLogo, 2001.  Updated 2003.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (1996).  NetLogo Sand model.
; http://ccl.northwestern.edu/netlogo/models/Sand.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; In other publications, please use:
; Copyright 1998 by Uri Wilensky.  All rights reserved.  See
; http://ccl.northwestern.edu/netlogo/models/Sand
; for terms of use.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
264
10
679
446
40
40
5.0
0
10
1
1
1

CC-WINDOW
3
262
255
445
Command Center

BUTTON
135
41
245
97
NIL
go
T
1
T
OBSERVER
T

BUTTON
10
41
120
97
NIL
setup
NIL
1
T
OBSERVER
T

SLIDER
10
105
245
138
release-chance
release-chance
0.0
100.0
100.0
1.0
1
%

SLIDER
127
207
237
240
density
density
0.0
50.0
10.0
1.0
1
%

BUTTON
17
207
127
240
NIL
dump-sand
NIL
1
T
OBSERVER
T

SLIDER
47
140
219
173
spacing
spacing
2
15
3
1
1
NIL

@#$#@#$#@
WHAT IS IT?
-----------
This is a model of how sand particles interact with each other.  In this environment, all sand particles on the screen try to move down if any of the following four rules apply.  The four rules are:

1.) If there is nothing directly beneath you, move down.
2.) If there is something beneath you and to the lower right, move down and to the left.
3.) if there is something beneath you and to your lower left, move down and to the right.
4.) If there is only something directly beneath you, move down and either left or right at random.


HOW TO USE IT?
--------------
GO: Starts and stops the simulation.

SETUP: Sets up the model.

RELEASE-CHANCE: Determines the percent chance that a particle of sand will fall from a spout each turn (default value of 100%).

SPACING: Determines how long a spout waits before releasing the next particle of sand.

DUMP SAND: Dumps sand on all of the model according to the density leve.  Use this only after you have pressed SETUP.

DENSITY: Sets the density of sand particles dumped in DUMP SAND (default value of 25%).  For example setting the density to 40 will, at random fill 40 percent of the patches with sand.


THINGS TO NOTICE
----------------
Observe how sand will roll down a "mountain" of sand particles.  Consider how this phenomenon is supported by the rules.  Notice the patterns that form when two "mountains" of sand grow into each other.


THINGS TO TRY
-------------
Observe how the spouts will form uniform pyramids of sand.  Try DUMP SAND at a low density once you have a relatively large pyramid shape.  How does this effect the shape of the pyramid?  Does the pyramid ever return to its original shape?

Try decreasing RELEASE-CHANCE.  What effect does this have on the growth rate of sand "mountains"?

Set the SPACING to 1.  (You'll have to edit the slider, since the normal minimum is 2.)  What happens?  Is this just a limitation of the model rules, or does it have some plausible physical interpretation?


EXTENDING THE MODEL
-------------------
In the procedures tab, notice the variable spout-space.  Try changing the number of spouts at the top of the screen by changing spout-space.

Does this model accurately reflect how sand behaves?  If not what rules could you devise to more accurately model sand's behavior?  How could they be incorporated into the model?

What effect does weight have on sand particles?  Should particles with lots of particles above them behave differently?  If so, how would this change the rules?

Try simulating erosion with this model.  How could you simulate wind?  What effect would this have on the shape of the piles?  How could you simulate rain?  What effect would this have on the shape of the piles?


NETLOGO FEATURES
------------------
Notice how the model stores an agentset in a variable, spout-patches.  It is initialized with the agentset of the patches where the spouts are located.  Subsequently this variable can be used in an ask command just like the default agentsets of "turtles" and "patches."  Since the agentset is computed once, ahead of time, the models runs faster than if the agentset were recomputed at every step.


CREDITS AND REFERENCES
----------------------
To refer to this model in academic publications, please use: Wilensky, U. (1996).  NetLogo Sand model. http://ccl.northwestern.edu/netlogo/models/Sand. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

In other publications, please use: Copyright 1996 by Uri Wilensky.  All rights reserved.  See http://ccl.northwestern.edu/netlogo/models/Sand for terms of use.
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

ant
true
0
Polygon -7566196 true true 136 61 129 46 144 30 119 45 124 60 114 82 97 37 132 10 93 36 111 84 127 105 172 105 189 84 208 35 171 11 202 35 204 37 186 82 177 60 180 44 159 32 170 44 165 60
Polygon -7566196 true true 150 95 135 103 139 117 125 149 137 180 135 196 150 204 166 195 161 180 174 150 158 116 164 102
Polygon -7566196 true true 149 186 128 197 114 232 134 270 149 282 166 270 185 232 171 195 149 186 149 186
Polygon -7566196 true true 225 66 230 107 159 122 161 127 234 111 236 106
Polygon -7566196 true true 78 58 99 116 139 123 137 128 95 119
Polygon -7566196 true true 48 103 90 147 129 147 130 151 86 151
Polygon -7566196 true true 65 224 92 171 134 160 135 164 95 175
Polygon -7566196 true true 235 222 210 170 163 162 161 166 208 174
Polygon -7566196 true true 249 107 211 147 168 147 168 150 213 150

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee
true
0
Polygon -256 true false 152 149 77 163 67 195 67 211 74 234 85 252 100 264 116 276 134 286 151 300 167 285 182 278 206 260 220 242 226 218 226 195 222 166
Polygon -16777216 true false 150 149 128 151 114 151 98 145 80 122 80 103 81 83 95 67 117 58 141 54 151 53 177 55 195 66 207 82 211 94 211 116 204 139 189 149 171 152
Polygon -7566196 true true 151 54 119 59 96 60 81 50 78 39 87 25 103 18 115 23 121 13 150 1 180 14 189 23 197 17 210 19 222 30 222 44 212 57 192 58
Polygon -16777216 true false 70 185 74 171 223 172 224 186
Polygon -16777216 true false 67 211 71 226 224 226 225 211 67 211
Polygon -16777216 true false 91 257 106 269 195 269 211 255
Line -1 false 144 100 70 87
Line -1 false 70 87 45 87
Line -1 false 45 86 26 97
Line -1 false 26 96 22 115
Line -1 false 22 115 25 130
Line -1 false 26 131 37 141
Line -1 false 37 141 55 144
Line -1 false 55 143 143 101
Line -1 false 141 100 227 138
Line -1 false 227 138 241 137
Line -1 false 241 137 249 129
Line -1 false 249 129 254 110
Line -1 false 253 108 248 97
Line -1 false 249 95 235 82
Line -1 false 235 82 144 100

bird1
false
0
Polygon -7566196 true true 2 6 2 39 270 298 297 298 299 271 187 160 279 75 276 22 100 67 31 0

bird2
false
0
Polygon -7566196 true true 2 4 33 4 298 270 298 298 272 298 155 184 117 289 61 295 61 105 0 43

boat1
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 33 230 157 182 150 169 151 157 156
Polygon -7566196 true true 149 55 88 143 103 139 111 136 117 139 126 145 130 147 139 147 146 146 149 55

boat2
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 157 54 175 79 174 96 185 102 178 112 194 124 196 131 190 139 192 146 211 151 216 154 157 154
Polygon -7566196 true true 150 74 146 91 139 99 143 114 141 123 137 126 131 129 132 139 142 136 126 142 119 147 148 147

boat3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7566196 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
true
0
Polygon -7566196 true true 45 255 255 255 255 45 45 45

butterfly1
true
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7566196 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7566196 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7566196 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7566196 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7566196 true 167 47 159 82
Line -7566196 true 136 47 145 81
Circle -7566196 true true 165 45 8
Circle -7566196 true true 134 45 6
Circle -7566196 true true 133 44 7
Circle -7566196 true true 133 43 8

circle
false
0
Circle -7566196 true true 35 35 230

person
false
0
Circle -7566196 true true 155 20 63
Rectangle -7566196 true true 158 79 217 164
Polygon -7566196 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7566196 true true 216 83 267 123 248 143 215 107
Polygon -7566196 true true 167 163 145 234 183 234 183 163
Polygon -7566196 true true 195 163 195 233 227 233 206 159

spacecraft
true
0
Polygon -7566196 true true 150 0 180 135 255 255 225 240 150 180 75 240 45 255 120 135

thin-arrow
true
0
Polygon -7566196 true true 150 0 0 150 120 150 120 293 180 293 180 150 300 150

truck-down
false
0
Polygon -7566196 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8716033 true false 195 75 195 120 240 120 240 75
Polygon -8716033 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7566196 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8716033 true false 90 210 105 225 120 210
Polygon -8716033 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7566196 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8716033 true false 210 210 195 225 180 210
Polygon -8716033 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7566196 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

wolf-left
false
3
Polygon -6524078 true true 117 97 91 74 66 74 60 85 36 85 38 92 44 97 62 97 81 117 84 134 92 147 109 152 136 144 174 144 174 103 143 103 134 97
Polygon -6524078 true true 87 80 79 55 76 79
Polygon -6524078 true true 81 75 70 58 73 82
Polygon -6524078 true true 99 131 76 152 76 163 96 182 104 182 109 173 102 167 99 173 87 159 104 140
Polygon -6524078 true true 107 138 107 186 98 190 99 196 112 196 115 190
Polygon -6524078 true true 116 140 114 189 105 137
Rectangle -6524078 true true 109 150 114 192
Rectangle -6524078 true true 111 143 116 191
Polygon -6524078 true true 168 106 184 98 205 98 218 115 218 137 186 164 196 176 195 194 178 195 178 183 188 183 169 164 173 144
Polygon -6524078 true true 207 140 200 163 206 175 207 192 193 189 192 177 198 176 185 150
Polygon -6524078 true true 214 134 203 168 192 148
Polygon -6524078 true true 204 151 203 176 193 148
Polygon -6524078 true true 207 103 221 98 236 101 243 115 243 128 256 142 239 143 233 133 225 115 214 114

wolf-right
false
3
Polygon -6524078 true true 170 127 200 93 231 93 237 103 262 103 261 113 253 119 231 119 215 143 213 160 208 173 189 187 169 190 154 190 126 180 106 171 72 171 73 126 122 126 144 123 159 123
Polygon -6524078 true true 201 99 214 69 215 99
Polygon -6524078 true true 207 98 223 71 220 101
Polygon -6524078 true true 184 172 189 234 203 238 203 246 187 247 180 239 171 180
Polygon -6524078 true true 197 174 204 220 218 224 219 234 201 232 195 225 179 179
Polygon -6524078 true true 78 167 95 187 95 208 79 220 92 234 98 235 100 249 81 246 76 241 61 212 65 195 52 170 45 150 44 128 55 121 69 121 81 135
Polygon -6524078 true true 48 143 58 141
Polygon -6524078 true true 46 136 68 137
Polygon -6524078 true true 45 129 35 142 37 159 53 192 47 210 62 238 80 237
Line -16777216 false 74 237 59 213
Line -16777216 false 59 213 59 212
Line -16777216 false 58 211 67 192
Polygon -6524078 true true 38 138 66 149
Polygon -6524078 true true 46 128 33 120 21 118 11 123 3 138 5 160 13 178 9 192 0 199 20 196 25 179 24 161 25 148 45 140
Polygon -6524078 true true 67 122 96 126 63 144

@#$#@#$#@
NetLogo 2.0beta5
@#$#@#$#@
setup
set release-chance 80
repeat 200 [ go ]
@#$#@#$#@
@#$#@#$#@
