globals [
  initial-elevation    ;; initial elevation of the terrain
]

breeds [
  water-sources    ;; turtles from which water flows
]

patches-own [
  elevation            ;; elevation of the terrain (0-low thru 100-high)
  soil-type            ;; soil type of the patch
  water-level          ;; amount of water on the patch
  
  flow-direction-x     ;; direction in which the water is flowing (delta x)
  flow-direction-y     ;; (delta y)
]

;; setup the model for use
to setup
  ca
  reset
    
  setup-globals
  initialize-water-sources
  initialize-terrain
    
  draw-terrain
end

;; remove all current water-sources
to reset
  ask water-sources [die]
end

;; setup global variables
to setup-globals
  set initial-elevation 50
end

;; create and initialize water sources
to initialize-water-sources
  create-custom-water-sources number-of-water-sources [
    set color red
    set size 2

    ;; randomly locate water source
    right random 360
    forward random screen-size-x
    set heading 0
  ]
end

;; setup the terrain
to initialize-terrain
  ask patches [
    set elevation random 100
    set water-level 0
  ]

  ;; give the terrain the specified smoothness by diffusing    
  repeat terrain-smoothness [ diffuse elevation 0.5 ]
end

to draw-terrain
  ask patches [ color-patch ]
end

;; color the terrain appropriately
to color-patch    ;; patch procedure
  ifelse water-level <= 0
    [ set pcolor scale-color gray elevation 0 100 ]
  [ifelse water-level < 10
    [ set pcolor 107 ]
  [ifelse water-level < 25
    [ set pcolor 106 ]
  [ifelse water-level < 50 
    [ set pcolor 105 ]
  [set pcolor 104]]]]
end

to go
  ask water-sources [ release-water ]
  ask patches with [ water-level > 0 ] [ flow-water ]
  draw-terrain
end

to release-water    ;; water-source procedure
  locals [ local-patch ]
  set local-patch patch-here
  set (water-level-of local-patch) (water-level-of local-patch) + water-flow-volume
end

;; allow any "overflow" water to flow to adjacent patches.  also erode and deposit soil.
to flow-water    ;; patch procedure
  locals [ 
    lower-neighbors 
    meniscus-height 
    lowest-neighbor 
    amount-to-move 
    temp-received-from source 
  ]
    
  ;; do some evaporation 
  set water-level water-level - evaporation-amount
    
  if water-level <= 0 [ stop ]
        
  set meniscus-height elevation + water-level
  set lower-neighbors neighbors with [ (elevation + water-level < meniscus-height) ]
    
  ;; move all excess water to the lowest neighbor
  if any? lower-neighbors [
     
    ;; weight the neighbor in the direction-of-flow more heavily
    set lowest-neighbor max-one-of lower-neighbors [ meniscus-height - (elevation + water-level) 
             - ((boolean-to-num (flow-target? myself self)) * 10) ]
             
    ;; remove the water from this patch
    set amount-to-move (meniscus-height - (elevation-of lowest-neighbor + water-level-of lowest-neighbor)) * 0.5
    set water-level water-level - amount-to-move
        
    ;; give the water to the neighbor and remember which direction it came from
    ask lowest-neighbor [ 
      set water-level water-level + amount-to-move 
      set flow-direction-x (pxcor-of self - pxcor-of myself)
      set flow-direction-y (pycor-of self - pycor-of myself)
    ]
        
    ;; do erosion and sediment-movement 
    ;; weight it by how much water is moving and by how hard the soil is
    set amount-to-move (amount-to-move - (amount-to-move * (soil-hardness / 100)))
    if elevation > 0 [ set elevation elevation - (0.10 * amount-to-move) ]    ;; remove sediment
    ask lowest-neighbor [ set elevation elevation + (0.03 * amount-to-move) ] ;; deposit sediment
        
    ;; do some erosion of the major flow-targets
    ask flow-targets-major [
      set elevation elevation - (0.05 * amount-to-move)                                                ;; remove sediment
      set (elevation-of lowest-neighbor) ((elevation-of lowest-neighbor) - (0.01 * amount-to-move))    ;; deposit sediment
    ]
        
    ;; do some cleanup (if there were lower neighbors)
    set meniscus-height elevation + water-level
  ]
    
  ;; Do some cleanup (regardless of lower neighbors), all bounds checking
  if elevation < 0 [ set elevation 0 ]
  if elevation > 100 [ set elevation 100 ]
  if water-level < 0 [ set water-level 0 ]
end

;; report true if target is the patch in the direction that the water is flowing in.
;; report false otherwise.
to-report flow-target? [source target]
  report (pxcor-of target = pxcor-of source + flow-direction-x-of source)
    and (pycor-of target = pycor-of source + flow-direction-y-of source)
end

;; report the neighbors that are perpendicular to the flow direction
to-report flow-targets-major    ;; patch procedure
  report neighbors with [ (pxcor = pxcor-of myself + flow-direction-x-of myself)
    and (pycor = pycor-of myself + flow-direction-y-of myself) ]
end

;; convert a true/false value into a number as follows:
;; true converts to 1 and false converts to 0
to-report boolean-to-num [boolean-value]
  ifelse boolean-value = false [ report 0 ] [ report 1 ]
end

;; modify the elevation of the patch where the mouse is clicked on
to terra-form
  if mouse-down? [
    ask (patch round mouse-xcor round mouse-ycor) [
      ifelse raise-terrain? = true 
        [ set elevation elevation + 2 ]
        [ set elevation elevation - 2 ]
      color-patch
    ]
  ]
end


; *** NetLogo Model Copyright Notice ***
;
; This model was created as part of the projects:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN
; CLASSROOMS and INTEGRATED SIMULATION AND MODELING ENVIRONMENT.
; The project gratefully acknowledges the support of the
; National Science Foundation (REPP & ROLE programs) -- grant numbers 
; REC #9814682 and REC-0126227.
;
; Copyright 2004 by Uri Wilensky.  All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (2004).  NetLogo Erosion model.
; http://ccl.northwestern.edu/netlogo/models/Erosion.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; In other publications, please use:
; Copyright 2004 Uri Wilensky.  All rights reserved.
; See http://ccl.northwestern.edu/netlogo/models/Erosion
; for terms of use.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
321
10
735
445
50
50
4.0
1
10
1
1
1

CC-WINDOW
321
453
736
515
Command Center

BUTTON
48
112
114
145
NIL
setup
NIL
1
T
OBSERVER
T

SLIDER
12
30
245
63
terrain-smoothness
terrain-smoothness
0
30
4
1
1
NIL

SLIDER
12
67
245
100
number-of-water-sources
number-of-water-sources
1
10
1
1
1
NIL

SLIDER
17
196
252
229
water-flow-volume
water-flow-volume
0
25
5
1
1
NIL

BUTTON
135
112
198
145
NIL
go
T
1
T
OBSERVER
NIL

SLIDER
17
233
252
266
evaporation-amount
evaporation-amount
0
0.25
0.02
0.01
1
NIL

TEXTBOX
9
10
139
28
Setup information:

TEXTBOX
13
176
172
194
Environmental parameters:

TEXTBOX
14
329
138
347
Terrain modification:

BUTTON
19
347
132
380
terra-form
terra-form
T
1
T
OBSERVER
T

SLIDER
17
270
252
303
soil-hardness
soil-hardness
1
100
45
1
1
NIL

SWITCH
138
348
269
381
raise-terrain?
raise-terrain?
1
1
-1000

@#$#@#$#@
WHAT IS IT?
-----------
This model is a simulation of soil erosion by water.  The user is presented with a randomly-generated terrain with one or more water sources located throughout.  As water flows from each source, it erodes the terrain below.  Water flow features change as the terrain takes on new characteristics as a result of this erosion.  Environmental modifications, such as changes in water flow volume, variations in evaporation rates, and terra-forming, may also be introduced by the user. 


HOW IT WORKS
------------
To illustrate the concept of erosion in a straightforward manner, the model uses a naive model of flowing water to generate a reasonable approximation of the phenomenon.  Essentially, water flows to the lowest adjacent terrain patch, as long as the terrain patch is lower than the source.  There is also a rudimentary inertial model for the water that gives some additional weight to the adjacent patch in the direction the water is currently flowing.  However, the model does not employ complex fluid dynamics calculations to simulate the water flow. 

The soil is represented by gray patches.  The lighter the patch, the higher the elevation. Water is represented by blue patches.  Deeper water is represented by a darker blue.  There is no way to tell the elevation of the terrain beneath a blue water patch unless the water drains off of the patch.

The water itself originates from "water sources," which have an adjustable rate of flow.  The water may evaporate once it is on the ground, depending on the user's slider settings.  The erosion of the soil is caused by water flowing over it.  Soil hardness can be adjusted, and hard soil erodes less quickly than soft soil.


HOW TO USE IT
-------------
The SETUP button generates a random terrain with water sources in random locations.

The GO button runs the erosion simulation. 

The TERRAIN-SMOOTHNESS slider determines the smoothness of the terrain during setup.  Higher values on the slider give smoother terrain, with more uniform elevations.  Lower values give rougher terrain, with more variation in elevation.

The NUMBER-OF-WATER-SOURCES slider determines how many water sources the terrain will have.

The WATER-FLOW-VOLUME slider controls how much water will be released from each water source while the simulation is running.  Higher values cause more water to flow out of the sources, while a value of 0 will stop the flow of water from the sources.

The EVAPORATION-AMOUNT slider controls how much water evaporates from each patch while the simulation is running.  Higher values cause the water to evaporate quickly.  With a value of 0, all of the water remains on the terrain. 

The SOIL-HARDNESS slider controls how "hard," or resistant to erosion the soil is.  Higher values will cause the soil to be harder, and less likely to erode, while lower values will cause the soil to erode more quickly.  A value of 100 means that the soil will not erode at all.

The TERRA-FORM button allows the user to change the elevation of a particular terrain patch by clicking on it.  It works in combination with the RAISE-TERRAIN? switch, which determines whether the terra-form tool will raise or lower the patch that is clicked on by the user.

The RAISE-TERRAIN? switch works with the TERRA-FORM button.  When the switch is in the "on" position, the terrain elevation will be raised when the user clicks on a patch.  When it is in the "off" position, the terrain will be lowered.


THINGS TO NOTICE
----------------
River-like features are more likely to form with relatively rough terrain.  Smooth terrain often leads to "pooling" of water in large areas, while rougher terrain may develop more "finger-like" waterways.

Flooding the system with water by increasing flow volume and eliminating evaporation may produce large, smooth basins that can be examined by draining the water.

The system is fairly dynamic.  Even when flow volume is cut off completely along with evaporation, water continues to ebb and flow around the terrain and perform erosion until an equilibrium is reached.


THINGS TO TRY
-------------
MODIFY THE TERRAIN - Small changes in the terrain can lead to big changes in the flow and pooling of the water.  What happens if a dam (a strip of raised terrain) is placed through a flow path?  What if a stable system has a "crater"-like depression introduced, similar to a meteorite impact?

DRAIN THE WATER AND OBSERVE THE TERRAIN - Sometimes, the best way to observe the results of the soil erosion on the terrain is to "drain" the water.  Set the WATER-FLOW-VOLUME slider to 0 and increase the EVAPORATION-AMOUNT to a high value.  The water should quickly evaporate from the system.  It is often possible to see how the terrain has been smoothed and carved out by the water.

EXPERIMENT WITH SOIL HARDNESS - Soil hardness can have a big impact on how water flows within the system.  How does the SOIL-HARDNESS affect the tendency of the water to collect in pools?

MULTIPLE WATER SOURCES - Increasing the NUMBER-OF-WATER-SOURCES can increase the complexity of the system and generate some interesting phenomena.  Be careful, though, because the simulation can become slower as more water sources are added.


EXTENDING THE MODEL
-------------------
- Improve the water flow model.  Currently, all of the water simply flows to the lowest neighbor (with some weight given to neighbors in the current direction of flow as a rudimentary inertial model.)  A more accurate model would allow smaller amounts of water to flow out to multiple neighbors if all are lower. 

- Introduce macro-terrain features such as mountains.  It is difficult to observe river-like water formations in this model because the terrain features are relatively small.  Modifying the terrain generator to create "larger" terrain features with water sources at the top of elevated regions might lead to more river-like water flow.

- Allow user-located water sources.  Currently water sources are located at random.  As a result, their positions do not always lead to interesting water flows and erosion.  Allowing the user to place the water sources would allow for more "what-if" experimentation using the model.

- Add multiple soil types to the terrain.  Terrain with less homogenous soil-hardness values may result in more a more dynamic system. 


NETLOGO FEATURES
----------------
A workaround was used to implement the terra-forming interface.  Although it may have been more intuitive to have two separate TERRA-FORM buttons, one for RAISE-TERRAIN? and one for LOWER-TERRAIN, there was no reasonable way to turn a forever button off when another is clicked.  Instead, a generic TERRA-FORM button is used in combination with a RAISE-TERRAIN? switch. 


CREDITS AND REFERENCES
----------------------
Original implementation: Greg Dunham, for the Center for Connected Learning and Computer-Based Modeling.

To refer to this model in academic publications, please use: Wilensky, U. (2004). NetLogo Erosion model. http://ccl.northwestern.edu/netlogo/models/Erosion. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

In other publications, please use: Copyright 2004 Uri Wilensky. All rights reserved. See http://ccl.northwestern.edu/netlogo/models/Erosion for terms of use.
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

ant
true
0
Polygon -7566196 true true 136 61 129 46 144 30 119 45 124 60 114 82 97 37 132 10 93 36 111 84 127 105 172 105 189 84 208 35 171 11 202 35 204 37 186 82 177 60 180 44 159 32 170 44 165 60
Polygon -7566196 true true 150 95 135 103 139 117 125 149 137 180 135 196 150 204 166 195 161 180 174 150 158 116 164 102
Polygon -7566196 true true 149 186 128 197 114 232 134 270 149 282 166 270 185 232 171 195 149 186 149 186
Polygon -7566196 true true 225 66 230 107 159 122 161 127 234 111 236 106
Polygon -7566196 true true 78 58 99 116 139 123 137 128 95 119
Polygon -7566196 true true 48 103 90 147 129 147 130 151 86 151
Polygon -7566196 true true 65 224 92 171 134 160 135 164 95 175
Polygon -7566196 true true 235 222 210 170 163 162 161 166 208 174
Polygon -7566196 true true 249 107 211 147 168 147 168 150 213 150

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee
true
0
Polygon -256 true false 152 149 77 163 67 195 67 211 74 234 85 252 100 264 116 276 134 286 151 300 167 285 182 278 206 260 220 242 226 218 226 195 222 166
Polygon -16777216 true false 150 149 128 151 114 151 98 145 80 122 80 103 81 83 95 67 117 58 141 54 151 53 177 55 195 66 207 82 211 94 211 116 204 139 189 149 171 152
Polygon -7566196 true true 151 54 119 59 96 60 81 50 78 39 87 25 103 18 115 23 121 13 150 1 180 14 189 23 197 17 210 19 222 30 222 44 212 57 192 58
Polygon -16777216 true false 70 185 74 171 223 172 224 186
Polygon -16777216 true false 67 211 71 226 224 226 225 211 67 211
Polygon -16777216 true false 91 257 106 269 195 269 211 255
Line -1 false 144 100 70 87
Line -1 false 70 87 45 87
Line -1 false 45 86 26 97
Line -1 false 26 96 22 115
Line -1 false 22 115 25 130
Line -1 false 26 131 37 141
Line -1 false 37 141 55 144
Line -1 false 55 143 143 101
Line -1 false 141 100 227 138
Line -1 false 227 138 241 137
Line -1 false 241 137 249 129
Line -1 false 249 129 254 110
Line -1 false 253 108 248 97
Line -1 false 249 95 235 82
Line -1 false 235 82 144 100

bird1
false
0
Polygon -7566196 true true 2 6 2 39 270 298 297 298 299 271 187 160 279 75 276 22 100 67 31 0

bird2
false
0
Polygon -7566196 true true 2 4 33 4 298 270 298 298 272 298 155 184 117 289 61 295 61 105 0 43

boat1
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 33 230 157 182 150 169 151 157 156
Polygon -7566196 true true 149 55 88 143 103 139 111 136 117 139 126 145 130 147 139 147 146 146 149 55

boat2
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 157 54 175 79 174 96 185 102 178 112 194 124 196 131 190 139 192 146 211 151 216 154 157 154
Polygon -7566196 true true 150 74 146 91 139 99 143 114 141 123 137 126 131 129 132 139 142 136 126 142 119 147 148 147

boat3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7566196 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
true
0
Polygon -7566196 true true 45 255 255 255 255 45 45 45

butterfly1
true
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7566196 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7566196 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7566196 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7566196 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7566196 true 167 47 159 82
Line -7566196 true 136 47 145 81
Circle -7566196 true true 165 45 8
Circle -7566196 true true 134 45 6
Circle -7566196 true true 133 44 7
Circle -7566196 true true 133 43 8

circle
false
0
Circle -7566196 true true 35 35 230

person
false
0
Circle -7566196 true true 155 20 63
Rectangle -7566196 true true 158 79 217 164
Polygon -7566196 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7566196 true true 216 83 267 123 248 143 215 107
Polygon -7566196 true true 167 163 145 234 183 234 183 163
Polygon -7566196 true true 195 163 195 233 227 233 206 159

sheep
false
15
Rectangle -1 true true 90 75 270 225
Circle -1 true true 15 75 150
Rectangle -16777216 true false 81 225 134 286
Rectangle -16777216 true false 180 225 238 285
Circle -16777216 true false 1 88 92

spacecraft
true
0
Polygon -7566196 true true 150 0 180 135 255 255 225 240 150 180 75 240 45 255 120 135

thin-arrow
true
0
Polygon -7566196 true true 150 0 0 150 120 150 120 293 180 293 180 150 300 150

truck-down
false
0
Polygon -7566196 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8716033 true false 195 75 195 120 240 120 240 75
Polygon -8716033 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7566196 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8716033 true false 90 210 105 225 120 210
Polygon -8716033 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7566196 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8716033 true false 210 210 195 225 180 210
Polygon -8716033 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7566196 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

wolf
false
0
Rectangle -7566196 true true 15 105 105 165
Rectangle -7566196 true true 45 90 105 105
Polygon -7566196 true true 60 90 83 44 104 90
Polygon -16777216 true false 67 90 82 59 97 89
Rectangle -1 true false 48 93 59 105
Rectangle -16777216 true false 51 96 55 101
Rectangle -16777216 true false 0 121 15 135
Rectangle -16777216 true false 15 136 60 151
Polygon -1 true false 15 136 23 149 31 136
Polygon -1 true false 30 151 37 136 43 151
Rectangle -7566196 true true 105 120 263 195
Rectangle -7566196 true true 108 195 259 201
Rectangle -7566196 true true 114 201 252 210
Rectangle -7566196 true true 120 210 243 214
Rectangle -7566196 true true 115 114 255 120
Rectangle -7566196 true true 128 108 248 114
Rectangle -7566196 true true 150 105 225 108
Rectangle -7566196 true true 132 214 155 270
Rectangle -7566196 true true 110 260 132 270
Rectangle -7566196 true true 210 214 232 270
Rectangle -7566196 true true 189 260 210 270
Line -7566196 true 263 127 281 155
Line -7566196 true 281 155 281 192

wolf-left
false
3
Polygon -6524078 true true 117 97 91 74 66 74 60 85 36 85 38 92 44 97 62 97 81 117 84 134 92 147 109 152 136 144 174 144 174 103 143 103 134 97
Polygon -6524078 true true 87 80 79 55 76 79
Polygon -6524078 true true 81 75 70 58 73 82
Polygon -6524078 true true 99 131 76 152 76 163 96 182 104 182 109 173 102 167 99 173 87 159 104 140
Polygon -6524078 true true 107 138 107 186 98 190 99 196 112 196 115 190
Polygon -6524078 true true 116 140 114 189 105 137
Rectangle -6524078 true true 109 150 114 192
Rectangle -6524078 true true 111 143 116 191
Polygon -6524078 true true 168 106 184 98 205 98 218 115 218 137 186 164 196 176 195 194 178 195 178 183 188 183 169 164 173 144
Polygon -6524078 true true 207 140 200 163 206 175 207 192 193 189 192 177 198 176 185 150
Polygon -6524078 true true 214 134 203 168 192 148
Polygon -6524078 true true 204 151 203 176 193 148
Polygon -6524078 true true 207 103 221 98 236 101 243 115 243 128 256 142 239 143 233 133 225 115 214 114

wolf-right
false
3
Polygon -6524078 true true 170 127 200 93 231 93 237 103 262 103 261 113 253 119 231 119 215 143 213 160 208 173 189 187 169 190 154 190 126 180 106 171 72 171 73 126 122 126 144 123 159 123
Polygon -6524078 true true 201 99 214 69 215 99
Polygon -6524078 true true 207 98 223 71 220 101
Polygon -6524078 true true 184 172 189 234 203 238 203 246 187 247 180 239 171 180
Polygon -6524078 true true 197 174 204 220 218 224 219 234 201 232 195 225 179 179
Polygon -6524078 true true 78 167 95 187 95 208 79 220 92 234 98 235 100 249 81 246 76 241 61 212 65 195 52 170 45 150 44 128 55 121 69 121 81 135
Polygon -6524078 true true 48 143 58 141
Polygon -6524078 true true 46 136 68 137
Polygon -6524078 true true 45 129 35 142 37 159 53 192 47 210 62 238 80 237
Line -16777216 false 74 237 59 213
Line -16777216 false 59 213 59 212
Line -16777216 false 58 211 67 192
Polygon -6524078 true true 38 138 66 149
Polygon -6524078 true true 46 128 33 120 21 118 11 123 3 138 5 160 13 178 9 192 0 199 20 196 25 179 24 161 25 148 45 140
Polygon -6524078 true true 67 122 96 126 63 144

@#$#@#$#@
NetLogo 2.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
