turtles-own 
[
  nearby-classmates         ;; turtles within some specified radius
  closest-classmate         ;; the nearest turtle
  stopped?                  ;; if the turtle hasn't moved
  rule                      ;; the turtle's rule
  origin                    ;; the turtle's original position
  close-classmates          ;; turtles within the too-close range
  far-classmates            ;; turtles within the too-far range
  total-distance-moved      ;; total distance moved by the turtle
  last-patch                ;; last patch the turtle was on
]

globals 
[
  ticks
  num-patches               ;; used to measure the number of patches in a certain radius
]


;;
;; SETUP AND HELPERS
;;

to setup
  ca
  set-default-shape turtles "circle"
  set ticks 0
  make-turtles
  setup-plots
  update-plots
end

to make-turtles
  ifelse (num-patches-in-radius < num-turtles-to-create)
  [ user-message "There aren't enough patches in initial-radius to create the number "
    + "of turtles you've asked for.  Please make initial-radius larger or decrease "
    + "the number of turtles." ]
  [ ask patch 0 0 [
      ask-n-patches-sprout-turtle-with-rule-and-color num-random-min "random-min" violet
      ask-n-patches-sprout-turtle-with-rule-and-color num-random "random" brown
      ask-n-patches-sprout-turtle-with-rule-and-color num-random-away "random-away" pink
      ask-n-patches-sprout-turtle-with-rule-and-color num-open-min "open-min" blue
      ask-n-patches-sprout-turtle-with-rule-and-color num-open-min-max "open-min-max" orange ] ]
  set-common-variables
end

;; reports the number of patches available inside initial-radius
to-report num-patches-in-radius
  ask patch 0 0
  [ set num-patches count patches in-radius initial-radius ]
  report num-patches
end

;; reports the total number of turtles the user has requested
to-report num-turtles-to-create
  report num-random-min +
         num-random +
         num-random-away +
         num-open-min +
         num-open-min-max
end

;; ask n random patches without a turtle on them that are within initial-radius of the
;; asker to sprout a turtle with the rule set to turtle-rule and color to turtle-color
to ask-n-patches-sprout-turtle-with-rule-and-color [ n turtle-rule turtle-color ]
  ask random-n-of n (patches in-radius initial-radius with [not any? turtles-here])
  [ sprout 1
    [ set rule turtle-rule
      set color turtle-color ] ]
end

;; initializes turtle variables
;; also moves the turtles a bit so that they are a bit more randomly scattered
to set-common-variables
  ask turtles 
  [ set xcor xcor - .5 + random-float 1
    set ycor ycor - .5 + random-float 1
    set origin patch-here
    set stopped? false
    set total-distance-moved 0 ]
end


;;
;; GO AND TURTLE STRATEGIES
;;

to go
  if not any? turtles with [not stopped?] [ stop ]
  set ticks (ticks + 1)
  ask turtles [ 
    set last-patch patch-here
    if rule = "random-min" [ move-random-min ]
    if rule = "random" [ move-random ]
    if rule = "random-away" [ move-random-away ]
    if rule = "open-min" [ move-open-min ]
    if rule = "open-min-max" [ move-open-min-max ]
    set total-distance-moved (total-distance-moved + (distance last-patch))
  ]
  update-plots
end

;; set a random heading and move at 
;; each time step, with no stopping condition
to move-random ;; turtle procedure
  rt random 360
  avoid-walls
  fd step-size
end

;; turtle procedure: set a random heading and move until 
;; all other turtles are at least "too-close" away 
to move-random-min
  set nearby-classmates (turtles in-radius too-close) with [self != myself]
  ifelse any? nearby-classmates  ; if there aren't turtles nearby, stop, you are scattered
  [ rt random 360
    avoid-walls
    fd step-size 
    set stopped? false ]
  [ set stopped? true ]
end

;; set heading in the direction opposite
;; of the closest turtle, without stopping
to move-random-away ;; turtle procedure
  set closest-classmate min-one-of (turtles with [self != myself]) [ distance myself ]
  set heading (180 + towards-nowrap closest-classmate)
  avoid-walls
  fd step-size 
  set stopped? false
end

;; set heading towards the largest open space,
;; stopping when all other turtles are at least "too-close" away
to move-open-min ;; turtle procedure
  set nearby-classmates (turtles in-radius too-close) with [self != myself]
  ifelse any? nearby-classmates
  [ set heading (180 + (towardsxy-nowrap (mean values-from (nearby-classmates with [self != myself]) [xcor])
                                         (mean values-from (nearby-classmates with [self != myself]) [ycor])))
    avoid-walls
    fd step-size
    set stopped? false ]
  [ set stopped? true ]
end

;; when turtles are too close, move to an open space,
;; when turtles get too far, move in towards a more populated area, and otherwise, stop
to move-open-min-max ;; turtle procedure
  without-interruption 
  [ set close-classmates (turtles in-radius too-close) with [self != myself]
    set far-classmates (turtles in-radius too-far) with [self != myself]
    ifelse any? close-classmates  ; move to an open space
    [ set heading (180 + (towardsxy-nowrap (mean values-from (close-classmates with [self != myself]) [xcor])
                                           (mean values-from (close-classmates with [self != myself]) [ycor])))
      avoid-walls
      fd step-size
      set stopped? false ]
    [ ifelse not any? far-classmates  ; move to a more populated space in the 'room'
      [ set heading (towardsxy-nowrap (mean values-from (turtles with [self != myself]) [xcor])
                                      (mean values-from (turtles with [self != myself]) [ycor]))
        avoid-walls
        fd step-size
        set stopped? false ]
      [ set stopped? true ] ] ]
end

;; if a turtle gets to a wall, it turns around
to avoid-walls ;; turtle procedure
  if (pxcor-of patch-ahead 1 = screen-edge-x)
    ; what to do? turn around for now
  [ set heading (heading + 180) ]
  if (pycor-of patch-ahead 1 = screen-edge-y)
  [ set heading (heading + 180) ]
end

;;
;; PLOTTING
;;

to setup-plots
  set-current-plot "Average Distance from Origin"
  set-plot-x-range 0 30
  set-plot-y-range  0 5 ; set initial y range to half of graphics window size

  set-current-plot "Mobility of Scatterers"
  set-plot-x-range 0 5
  set-plot-y-range 0 (screen-edge-x)
end

to update-plots
  update-distance-plot
  update-concentric-histogram
end

;; for each type of turtle, plots the average distance of each
;; of the turtles from its starting spot
to update-distance-plot
  set-current-plot "Average Distance from Origin"
  plot-rule-mean "random-min"
  plot-rule-mean "random-away"
  plot-rule-mean "random"
  plot-rule-mean "open-min"
  plot-rule-mean "open-min-max"
end

;; if there are any turtles with turtle-rule as their rule, plot the
;; mean distance from the origin with the appropriate plot pen
to plot-rule-mean [ turtle-rule ]
  if any? (turtles with [rule = turtle-rule])
  [ set-current-plot-pen turtle-rule
    plot mean values-from (turtles with [rule = turtle-rule]) [distance origin] ]
end

;; a histogram of the total distance traveled by turtles,
;; grouped in concentric circles from the center patch
to update-concentric-histogram
  set-current-plot "Mobility of Scatterers"
  plot-pen-reset
  ; between the center patch and screen-edge-x/4
  set-plot-pen-color red
  if (any? turtles with [(distancexy-nowrap 0 0) <= (screen-edge-x / 4)])
  [ ask patch 0 0 
    [ plot mean values-from (turtles with [(distancexy-nowrap 0 0) <= (screen-edge-x / 4)]) 
                            [total-distance-moved] ] ]
  ; between screen-edge-x/4 and screen-edge-x/2
  if (any? turtles with [((distancexy-nowrap 0 0) > (screen-edge-x / 4)) and 
                         ((distancexy-nowrap 0 0) <= (screen-edge-x / 2))])
  [ set-plot-pen-color green
    ask patch 0 0 
    [ plot mean values-from (turtles with [((distancexy-nowrap 0 0) > (screen-edge-x / 4)) and 
                                           ((distancexy-nowrap 0 0) <= (screen-edge-x / 2))])
                            [total-distance-moved] ] ]
  ; between screen-edge-x/2 and (3/4)screen-edge-x
  if (any? turtles with [((distancexy-nowrap 0 0) > (screen-edge-x / 2)) and
                         ((distancexy-nowrap 0 0) <= (3 * screen-edge-x / 4))])
  [ set-plot-pen-color violet
    ask patch 0 0 
    [ plot mean values-from (turtles with [((distancexy-nowrap 0 0) > (screen-edge-x / 2)) and
                                           ((distancexy-nowrap 0 0) <= (3 * screen-edge-x / 4))])
                            [total-distance-moved] ] ]
  ; between (3/4)screen-edge-x and screen-edge-x
  if (any? turtles with [((distancexy-nowrap 0 0) > ((screen-edge-x * 3) / 4)) and
                         ((distancexy-nowrap 0 0) <= (screen-edge-x))])
  [ set-plot-pen-color orange
    ask patch 0 0 
    [ plot mean values-from (turtles with [((distancexy-nowrap 0 0) > ((screen-edge-x * 3) / 4)) and
                                           ((distancexy-nowrap 0 0) <= (screen-edge-x))])
                            [total-distance-moved] ] ]
  ; everything outside of screen-edge-x
  if (any? turtles with [(distancexy-nowrap 0 0) > screen-edge-x])
  [ set-plot-pen-color blue
    ask patch 0 0
    [ plot mean values-from (turtles with [(distancexy-nowrap 0 0) > screen-edge-x]) 
                            [total-distance-moved] ] ]
end


; *** NetLogo Model Copyright Notice ***
;
; This model was created as part of the projects:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN
; CLASSROOMS and INTEGRATED SIMULATION AND MODELING ENVIRONMENT.
; The project gratefully acknowledges the support of the
; National Science Foundation (REPP & ROLE programs) -- grant numbers 
; REC #9814682 and REC-0126227.
;
; Copyright 2004 by Uri Wilensky.  All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (2004).  NetLogo Scatter model.
; http://ccl.northwestern.edu/netlogo/models/Scatter.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; In other publications, please use:
; Copyright 2004 Uri Wilensky.  All rights reserved.
; See http://ccl.northwestern.edu/netlogo/models/Scatter
; for terms of use.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
276
10
709
464
23
23
9.0
1
10
1
1
1

CC-WINDOW
276
476
710
603
Command Center

MONITOR
193
10
261
59
ticks
ticks
0
1

SLIDER
36
68
240
101
initial-radius
initial-radius
0
20
10.0
0.5
1
NIL

SLIDER
724
118
919
151
num-random-min
num-random-min
0
200
150
1
1
NIL

SLIDER
730
397
926
430
num-random
num-random
0
200
0
1
1
NIL

BUTTON
20
10
90
59
NIL
setup
NIL
1
T
OBSERVER
T

BUTTON
106
10
176
59
NIL
go
T
1
T
OBSERVER
T

SLIDER
728
325
925
358
num-random-away
num-random-away
0
200
0
1
1
NIL

TEXTBOX
803
96
893
114
Violet

TEXTBOX
812
373
902
391
Brown

TEXTBOX
817
302
907
320
Pink

PLOT
14
148
263
372
Average Distance from Origin
time ticks
average distance
0.0
100.0
0.0
100.0
true
false
PENS
"random-min" 1.0 0 -8716033 true
"random-away" 1.0 0 -65413 true
"random" 1.0 0 -6524078 true
"open-min" 1.0 0 -16776961 true
"open-min-max" 1.0 0 -44544 true

SLIDER
724
10
919
43
too-close
too-close
0.1
5
1.0
0.1
1
NIL

SLIDER
724
51
919
84
too-far
too-far
0.1
5
1.5
0.1
1
NIL

TEXTBOX
805
230
895
248
Orange

SLIDER
726
254
922
287
num-open-min-max
num-open-min-max
0
200
0
1
1
NIL

TEXTBOX
810
163
900
181
Blue

SLIDER
725
185
921
218
num-open-min
num-open-min
0
200
0
1
1
NIL

SLIDER
37
107
241
140
step-size
step-size
0.1
2
1.0
0.1
1
NIL

PLOT
14
380
263
604
Mobility of Scatterers
circle number
total distance moved
0.0
5.0
0.0
1080.0
true
false
PENS
"default" 1.0 1 -16745473 true

@#$#@#$#@
WHAT IS IT?
-----------
This model simulates scattering, which takes place just before exercising in gym. The students start out all bunched up, and the teacher asks them to spread so that they may do jumping jacks without colliding. This simulation shows the spread of the group when the individual students follow simple rules to decide whether to move and where.

The scatterers move according to rules that were gleaned from several interviews with sixth-grade students. The students described the scattering process with words, using coins and drawing pictures. 


HOW IT WORKS
------------
This model implements several scattering rules, which the user can mix and match:

RANDOM-MIN: Move in a random direction until you are far enough away from all of your neighbors.

OPEN-MIN: Move into the largest open nearby space until you are far enough away from all of your neighbors.

OPEN-MIN-MAX: Move into the largest open nearby space until you are far enough away, but not too far. If you're too close, move away. If you're too far, move closer.

RANDOM-AWAY: Move in a random direction away from the person that is closest too you.

RANDOM: Move about randomly, disregarding all other scatterers.

The scattering students move with equal speeds, if they move at all. Two students cannot occupy the same location. Whether or not to move and where to move depends on each of the rules that are described. The color of the scattering students reflects the rule that they are following.

Random-min turtles (the violet ones) set their heading and move in a random direction if and only if there are turtles that are too close. Open-min turtles (blue) also stop when other turtles are too close. If there are turtles that are too close, they find the heading that will take them to the largest open space. 

The open-min-max turtles (orange) move to the largest open space if other turtles are too close. If the other turtles are too far away (that is, there aren't turtles within a certain space), the turtle in question moves to a more populated area.

Two of the scattering rules do not have stopping conditions, so they continue scattering infinitely. Random-away turtles (pink) look at the turtle closest to them and move in the opposite direction. Random turtles (brown) just run around in a random direction, never looking at the turtles around them.


HOW TO USE IT
-------------
Use the sliders to the right of the graphics window to specify the number of turtles to create with each rule. 

With the first two rules, the TOO-CLOSE slider sets the distance, in patches, that the turtles must be away from other turtles before stopping. The NUM-RANDOM-MIN slider indicates the number of turtles to create that move in a random direction, stopping when they are at least the distance specified by TOO-CLOSE from other turtles. Use the NUM-OPEN-MIN slider to specify how many turtles to create that move to the largest open space if there are turtles within TOO-CLOSE.

NUM-OPEN-MIN-MAX specifies the number of turtles to create that must have turtles within a certain range in order to stop. TOO-CLOSE indicates how far away other turtles must be for a turtle to stop, and TOO-FAR indicates how close the turtle in question must be to at least another turtle for it to stop.

The NUM-RANDOM-AWAY slider indicates the number of turtles to create that move away from the closest turtle, without ever stopping. NUM-RANDOM indicates the number of turtles that move in random directions without stopping.

To indicate the radius within which you want the turtles to be initially scattered, use the INITIAL-RADIUS slider. INITIAL-RADIUS must be large enough to fit the number of turtles indicated by the above sliders. See NetLogo Features, below.

To vary the distance that a turtle moves each time step, change the STEP-SIZE slider.

Press SETUP to create the number of turtles indicated, in the INITIAL-RADIUS specified. Press GO to start the model and the plots. 

The plot AVERAGE DISTANCE FROM ORIGIN shows the average distance that turtles of a certain rule have moved from their original position over time. It is color-coded to match the colors of the turtles. To observe the average distance of turtles of a certain rule, watch the line of the same color.

The MOBILITY OF SCATTERERS histogram displays the average total distance moved by turtles within a certain range away from the origin. Each of the bars plots the average total distance of turtles in five concentric circles radiating from the center patch. Note that this differs from that of the AVERAGE DISTANCE FROM ORIGIN plot, which measures the distance from the turtle's present spot to its original spot, in that it adds up each step taken by the turtle.

The TICKS monitor displays the number of clock cycles that GO has run.


THINGS TO NOTICE
----------------
Certain rules get to a settled, or scattered, state more quickly than others do. Which rules are better for efficient scattering?

Some of the rules produce a more ordered end formation than others. Why is this, and which ones exhibit this behavior?

When certain rules are mixed together, segregation occurs. That is, turtles of a certain rule tend to be surrounded by more turtles of the same rule than not. Which combinations of rules produce this segregation more than others?

Like two people walking towards each other down a hallway trying to avoid colliding, the rules of the turtles deciding their heading based on other turtles can conflict. For instance, several turtles moving to the largest open space may choose to move to the same open spot and, in doing so, move closer to the other turtles. This can form clusters of turtles, even when the group is spreading.

When observing the MOBILITY OF SCATTERERS plot, notice how scatterers farther on the outside will sometimes move a greater total distance or a smaller total distance, depending on the rule.

There are often threshold values where the scatterers will never settle down, and the model will not stop. For instance, if TOO-CLOSE is too great and there are too many turtles, they will never have enough room to completely scatter. 


THINGS TO TRY
-------------
When experimenting with the move-into-range turtles, vary the TOO-CLOSE and TOO-FAR sliders concurrently with the STEP-SIZE slider. If the step size is too big and the TOO-CLOSE and TOO-FAR values creating too narrow of a range, will the scatterers ever settle?

Try mixing rules to explore how turtles of different rules interact with each other.

Watch what happens when a few random-scatter turtles run around a set of turtles with stopping conditions, like move-to-open-space turtles.

Vary the STEP-SIZE slider, and see what effect this has on the model. Does a bigger step size make for more or less efficient scattering?

Try varying INITIAL-RADIUS to make the starting formation tighter or more spread out. 

Pen-down one turtle, and watch its path as it moves about the screen. How does it compare with the group?


EXTENDING THE MODEL
-------------------
Try to think of other rules that scatterers follow. For example, figure out rules to get the turtles to fill up the entire space. Alternatively, turtles could move towards a friend or away from an enemy. Also, try to think of stopping conditions other than being a certain distance from other turtles.

Turtles could have a variable "stubbornness," which indicates how likely a turtle is to move or not. A dawdle or friendliness variable could indicate a likeliness to hang around other turtles. 

Try giving the scatterers the ability to back track. For instance, if a scatterer moving to an open space finds that their movement takes them to a more populated area, they could move back to where they were before.

Allow turtle to have varying speeds or step sizes, simulating the differing stride lengths of individual scatterers

Devise other ways to model the scattering in the aggregate sense; for example, measure the density in a certain area.


NETLOGO FEATURES
----------------
The model creates turtles by asking patches to sprout a turtle initialized with a certain rule. Because a patch can only sprout one turtle, only a certain number of turtles can fit in a certain radius. The model verifies that the user hasn't asked for more turtles than can fit in the initial-radius specified to avoid an error.


CREDITS AND REFERENCES
----------------------
Original implementation: Stephanie Bezold, for the Center for Connected Learning.

To refer to this model in academic publications, please use: Wilensky, U. (2004). NetLogo Scatter model. http://ccl.northwestern.edu/netlogo/models/Scatter. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

In other publications, please use: Copyright 2004 Uri Wilensky. All rights reserved. See http://ccl.northwestern.edu/netlogo/models/Scatter for terms of use.
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

ant
true
0
Polygon -7566196 true true 136 61 129 46 144 30 119 45 124 60 114 82 97 37 132 10 93 36 111 84 127 105 172 105 189 84 208 35 171 11 202 35 204 37 186 82 177 60 180 44 159 32 170 44 165 60
Polygon -7566196 true true 150 95 135 103 139 117 125 149 137 180 135 196 150 204 166 195 161 180 174 150 158 116 164 102
Polygon -7566196 true true 149 186 128 197 114 232 134 270 149 282 166 270 185 232 171 195 149 186 149 186
Polygon -7566196 true true 225 66 230 107 159 122 161 127 234 111 236 106
Polygon -7566196 true true 78 58 99 116 139 123 137 128 95 119
Polygon -7566196 true true 48 103 90 147 129 147 130 151 86 151
Polygon -7566196 true true 65 224 92 171 134 160 135 164 95 175
Polygon -7566196 true true 235 222 210 170 163 162 161 166 208 174
Polygon -7566196 true true 249 107 211 147 168 147 168 150 213 150

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee
true
0
Polygon -256 true false 152 149 77 163 67 195 67 211 74 234 85 252 100 264 116 276 134 286 151 300 167 285 182 278 206 260 220 242 226 218 226 195 222 166
Polygon -16777216 true false 150 149 128 151 114 151 98 145 80 122 80 103 81 83 95 67 117 58 141 54 151 53 177 55 195 66 207 82 211 94 211 116 204 139 189 149 171 152
Polygon -7566196 true true 151 54 119 59 96 60 81 50 78 39 87 25 103 18 115 23 121 13 150 1 180 14 189 23 197 17 210 19 222 30 222 44 212 57 192 58
Polygon -16777216 true false 70 185 74 171 223 172 224 186
Polygon -16777216 true false 67 211 71 226 224 226 225 211 67 211
Polygon -16777216 true false 91 257 106 269 195 269 211 255
Line -1 false 144 100 70 87
Line -1 false 70 87 45 87
Line -1 false 45 86 26 97
Line -1 false 26 96 22 115
Line -1 false 22 115 25 130
Line -1 false 26 131 37 141
Line -1 false 37 141 55 144
Line -1 false 55 143 143 101
Line -1 false 141 100 227 138
Line -1 false 227 138 241 137
Line -1 false 241 137 249 129
Line -1 false 249 129 254 110
Line -1 false 253 108 248 97
Line -1 false 249 95 235 82
Line -1 false 235 82 144 100

bird1
false
0
Polygon -7566196 true true 2 6 2 39 270 298 297 298 299 271 187 160 279 75 276 22 100 67 31 0

bird2
false
0
Polygon -7566196 true true 2 4 33 4 298 270 298 298 272 298 155 184 117 289 61 295 61 105 0 43

boat1
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 33 230 157 182 150 169 151 157 156
Polygon -7566196 true true 149 55 88 143 103 139 111 136 117 139 126 145 130 147 139 147 146 146 149 55

boat2
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 157 54 175 79 174 96 185 102 178 112 194 124 196 131 190 139 192 146 211 151 216 154 157 154
Polygon -7566196 true true 150 74 146 91 139 99 143 114 141 123 137 126 131 129 132 139 142 136 126 142 119 147 148 147

boat3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7566196 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
true
0
Polygon -7566196 true true 45 255 255 255 255 45 45 45

butterfly1
true
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7566196 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7566196 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7566196 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7566196 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7566196 true 167 47 159 82
Line -7566196 true 136 47 145 81
Circle -7566196 true true 165 45 8
Circle -7566196 true true 134 45 6
Circle -7566196 true true 133 44 7
Circle -7566196 true true 133 43 8

circle
false
0
Circle -7566196 true true 35 35 230

person
false
0
Circle -7566196 true true 155 20 63
Rectangle -7566196 true true 158 79 217 164
Polygon -7566196 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7566196 true true 216 83 267 123 248 143 215 107
Polygon -7566196 true true 167 163 145 234 183 234 183 163
Polygon -7566196 true true 195 163 195 233 227 233 206 159

sheep
false
15
Rectangle -1 true true 90 75 270 225
Circle -1 true true 15 75 150
Rectangle -16777216 true false 81 225 134 286
Rectangle -16777216 true false 180 225 238 285
Circle -16777216 true false 1 88 92

spacecraft
true
0
Polygon -7566196 true true 150 0 180 135 255 255 225 240 150 180 75 240 45 255 120 135

thin-arrow
true
0
Polygon -7566196 true true 150 0 0 150 120 150 120 293 180 293 180 150 300 150

truck-down
false
0
Polygon -7566196 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8716033 true false 195 75 195 120 240 120 240 75
Polygon -8716033 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7566196 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8716033 true false 90 210 105 225 120 210
Polygon -8716033 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7566196 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8716033 true false 210 210 195 225 180 210
Polygon -8716033 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7566196 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

wolf
false
0
Rectangle -7566196 true true 15 105 105 165
Rectangle -7566196 true true 45 90 105 105
Polygon -7566196 true true 60 90 83 44 104 90
Polygon -16777216 true false 67 90 82 59 97 89
Rectangle -1 true false 48 93 59 105
Rectangle -16777216 true false 51 96 55 101
Rectangle -16777216 true false 0 121 15 135
Rectangle -16777216 true false 15 136 60 151
Polygon -1 true false 15 136 23 149 31 136
Polygon -1 true false 30 151 37 136 43 151
Rectangle -7566196 true true 105 120 263 195
Rectangle -7566196 true true 108 195 259 201
Rectangle -7566196 true true 114 201 252 210
Rectangle -7566196 true true 120 210 243 214
Rectangle -7566196 true true 115 114 255 120
Rectangle -7566196 true true 128 108 248 114
Rectangle -7566196 true true 150 105 225 108
Rectangle -7566196 true true 132 214 155 270
Rectangle -7566196 true true 110 260 132 270
Rectangle -7566196 true true 210 214 232 270
Rectangle -7566196 true true 189 260 210 270
Line -7566196 true 263 127 281 155
Line -7566196 true 281 155 281 192

wolf-left
false
3
Polygon -6524078 true true 117 97 91 74 66 74 60 85 36 85 38 92 44 97 62 97 81 117 84 134 92 147 109 152 136 144 174 144 174 103 143 103 134 97
Polygon -6524078 true true 87 80 79 55 76 79
Polygon -6524078 true true 81 75 70 58 73 82
Polygon -6524078 true true 99 131 76 152 76 163 96 182 104 182 109 173 102 167 99 173 87 159 104 140
Polygon -6524078 true true 107 138 107 186 98 190 99 196 112 196 115 190
Polygon -6524078 true true 116 140 114 189 105 137
Rectangle -6524078 true true 109 150 114 192
Rectangle -6524078 true true 111 143 116 191
Polygon -6524078 true true 168 106 184 98 205 98 218 115 218 137 186 164 196 176 195 194 178 195 178 183 188 183 169 164 173 144
Polygon -6524078 true true 207 140 200 163 206 175 207 192 193 189 192 177 198 176 185 150
Polygon -6524078 true true 214 134 203 168 192 148
Polygon -6524078 true true 204 151 203 176 193 148
Polygon -6524078 true true 207 103 221 98 236 101 243 115 243 128 256 142 239 143 233 133 225 115 214 114

wolf-right
false
3
Polygon -6524078 true true 170 127 200 93 231 93 237 103 262 103 261 113 253 119 231 119 215 143 213 160 208 173 189 187 169 190 154 190 126 180 106 171 72 171 73 126 122 126 144 123 159 123
Polygon -6524078 true true 201 99 214 69 215 99
Polygon -6524078 true true 207 98 223 71 220 101
Polygon -6524078 true true 184 172 189 234 203 238 203 246 187 247 180 239 171 180
Polygon -6524078 true true 197 174 204 220 218 224 219 234 201 232 195 225 179 179
Polygon -6524078 true true 78 167 95 187 95 208 79 220 92 234 98 235 100 249 81 246 76 241 61 212 65 195 52 170 45 150 44 128 55 121 69 121 81 135
Polygon -6524078 true true 48 143 58 141
Polygon -6524078 true true 46 136 68 137
Polygon -6524078 true true 45 129 35 142 37 159 53 192 47 210 62 238 80 237
Line -16777216 false 74 237 59 213
Line -16777216 false 59 213 59 212
Line -16777216 false 58 211 67 192
Polygon -6524078 true true 38 138 66 149
Polygon -6524078 true true 46 128 33 120 21 118 11 123 3 138 5 160 13 178 9 192 0 199 20 196 25 179 24 161 25 148 45 140
Polygon -6524078 true true 67 122 96 126 63 144

@#$#@#$#@
NetLogo 2.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
